==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/mi/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'Nga taonga kua tohaina ki: ingoa',
    'bulk_update_warn'	=> 'Kei te tata koe ki te whakatika i nga taonga o: kaiwhakamahi kaiwhakamahi_count. Kia mohio koe kaore e taea e koe te whakarereke i a koe ake huanga kaiwhakamahi me te whakamahi i tenei puka, me te whakarereke i to hoa ake.',
    'bulk_update_help'	=> 'Ko tenei puka ka taea e koe te whakahou i nga kaiwhakamahi maha i te wa kotahi. Whakakiia nga mara e hiahia ana koe ki te huri. Ko nga mara katoa e mahue ana ka noho tonu.',
    'current_assets'    => 'Ko nga taonga kei te tirotirohia i tenei wa ki tenei kaiwhakamahi',
    'clone'             => 'Kaiwhakamahi Tino',
    'contact_user'      => 'Whakapā: ingoa',
    'edit'              => 'Whakatika Kaiwhakamahi',
    'filetype_info'     => 'Ko nga piriti kua whakaaetia he png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, me te rar.',
    'history_user'      => 'Hītori mō: ingoa',
	'info'				=> 'Mōhiohio',
    'restore_user'		=> 'Pāwhiri ki konei kia whakahokia mai.',
    'last_login'        => 'Whakauru Whakamutunga',
    'ldap_config_text'  => 'Ka taea te kitea nga tautuhinga whirihora LDAP Kaiwhakahaere> Tautuhinga. Ko te (tahua) kua tohua te tauwāhi kua tohua mo nga kaiwhakamahi katoa kua kawemai.',
    'print_assigned'    => 'Print All Assigned',
    'software_user'     => 'Pūmanawa Kua tirotirohia ki: ingoa',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Tirohia te Kaiwhakamahi: ingoa',
    'usercsv'           => 'Kōnae CSV',
    'two_factor_admin_optin_help' => 'Ko to tautuhinga kaiwhakahaere o toianei kei te whakarite i te whakatinanatanga o te whakamotuhēhēnga-rua.',
    'two_factor_enrolled' => 'Kua whakauruhia te Pūrere 2FA',
    'two_factor_active'   => '2FA Mahi',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/mi/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'Nga taonga kua tohaina ki: ingoa',
    'bulk_update_warn'	=> 'Kei te tata koe ki te whakatika i nga taonga o: kaiwhakamahi kaiwhakamahi_count. Kia mohio koe kaore e taea e koe te whakarereke i a koe ake huanga kaiwhakamahi me te whakamahi i tenei puka, me te whakarereke i to hoa ake.',
    'bulk_update_help'	=> 'Ko tenei puka ka taea e koe te whakahou i nga kaiwhakamahi maha i te wa kotahi. Whakakiia nga mara e hiahia ana koe ki te huri. Ko nga mara katoa e mahue ana ka noho tonu.',
    'current_assets'    => 'Ko nga taonga kei te tirotirohia i tenei wa ki tenei kaiwhakamahi',
    'clone'             => 'Kaiwhakamahi Tino',
    'contact_user'      => 'Whakapā: ingoa',
    'edit'              => 'Whakatika Kaiwhakamahi',
    'filetype_info'     => 'Ko nga piriti kua whakaaetia he png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, me te rar.',
    'history_user'      => 'Hītori mō: ingoa',
    'info'				=> 'Mōhiohio',
    'restore_user'		=> 'Pāwhiri ki konei kia whakahokia mai.',
    'last_login'        => 'Whakauru Whakamutunga',
    'ldap_config_text'  => 'Ka taea te kitea nga tautuhinga whirihora LDAP Kaiwhakahaere> Tautuhinga. Ko te (tahua) kua tohua te tauwāhi kua tohua mo nga kaiwhakamahi katoa kua kawemai.',
    'print_assigned'    => 'Print All Assigned',
    'software_user'     => 'Pūmanawa Kua tirotirohia ki: ingoa',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Tirohia te Kaiwhakamahi: ingoa',
    'usercsv'           => 'Kōnae CSV',
    'two_factor_admin_optin_help' => 'Ko to tautuhinga kaiwhakahaere o toianei kei te whakarite i te whakatinanatanga o te whakamotuhēhēnga-rua.',
    'two_factor_enrolled' => 'Kua whakauruhia te Pūrere 2FA',
    'two_factor_active'   => '2FA Mahi',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'WARNING:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
